NAME

Zuzu::AST::Expr::Index - AST node for index expressions

DESCRIPTION

Represents one expression form in the abstract syntax tree and delegates evaluation to Zuzu::Runtime.

INHERITANCE

Inherits from Moo::Object.

ROLES

Consumes Zuzu::AST::Role::Node.

ATTRIBUTES

array

Type: Any.

Value stored in the array attribute.

index

Type: ConsumerOf["Zuzu::AST::Role::Node"].

Expression that evaluates to an index/key value.

METHODS

evaluate

Dispatches this AST node to the matching runtime evaluator.

SEE ALSO

Zuzu::AST::Role::Node.

Subclasses: none in this distribution.

COPYRIGHT AND LICENCE

Zuzu::AST::Expr::Index is copyright Toby Inkster.

It is free software; you may redistribute it and/or modify it under the terms of either the Artistic License 1.0 or the GNU General Public License version 2.