NAME
Zuzu::AST::Expr::DictGet - AST node for dictget expressions
DESCRIPTION
Represents one expression form in the abstract syntax tree and delegates evaluation to Zuzu::Runtime.
INHERITANCE
Inherits from Moo::Object.
ROLES
Consumes Zuzu::AST::Role::Node.
ATTRIBUTES
dict
Type: Any.
Value stored in the dict attribute.
key
Type: ConsumerOf["Zuzu::AST::Role::Node"].
Expression that evaluates to a dictionary key.
METHODS
evaluate
Dispatches this AST node to the matching runtime evaluator.
SEE ALSO
Zuzu::AST::Role::Node.
Subclasses: none in this distribution.
COPYRIGHT AND LICENCE
Zuzu::AST::Expr::DictGet is copyright Toby Inkster.
It is free software; you may redistribute it and/or modify it under the terms of either the Artistic License 1.0 or the GNU General Public License version 2.